@@ -450,11 +450,54 @@ def bright_neigh_exclusion_r(mag_bs, mag_limit_r, lunation):
         r_exclude = np.nanmax(np.column_stack((r_wings,
                                                r_trans,
                                                r_core)),
-                           axis=1)
+                              axis=1)
         r_exclude[mag_bs > mag_limit_r] = 0.
     return r_exclude
 
 
+def adjusted_brigh_neigh_mag(mag_bs, r, lunation):
+    """
+    returns the approximate adjusted magntidue of a
+    bright source at the position of a nearby fiber.
+    This is for the piecewise
+    appromixation used based on:
+    https://wiki.sdss.org/pages/viewpage.action?pageId=100173069
+
+    Parameters
+    ----------
+    mag_bs: float
+        The magniutde in the G band for the bright star
+
+    r: float or np.array
+        distance between fiber and bright star (in arcseconds)
+
+    lunation: str:
+        If the designmode is bright time ('bright') or dark
+        time ('dark')
+
+    Returns
+    -------
+    adjusted_mag_bs: float
+        The adjusted magntiude of the bright star in SDSS r-band
+    """
+    mag_wings = 8.2 + 0.05 * r + mag_bs
+    mag_trans = 4.5 + 0.25 * r + mag_bs
+    if lunation == 'bright':
+        mag_core = (r / 1.75) ** (1 / 0.6) + mag_bs
+    else:
+        mag_core = (r / 1.5) ** (1 / 0.8) + mag_bs
+    if isinstance(r, float):
+        adjusted_mag_bs = np.nanmin([mag_wings,
+                                     mag_trans,
+                                     mag_core])
+    else:
+        adjusted_mag_bs = np.nanmin(np.column_stack((mag_wings,
+                                                     mag_trans,
+                                                     mag_core)),
+                                    axis=1)
+    return adjusted_mag_bs
+
+
 def build_brigh_neigh_query(check_type, instrument, mag_lim,
                             racen, deccen):
     """
@@ -1143,11 +1186,23 @@ class DesignModeCheck(DesignMode):
             is robotID 1 to 500 robotID. True if robotID has intrument
             on fiber, False if not. If False, do not consider result from
             neigh_checks_des for this robotID
+
+        mag_adj_robo: np.array
+            If neigh_checks_des == False, reports the magntiude of nearby
+            bright source at the fiber position. If neigh_checks_des == True,
+            then no value reported (where NULL = -9999.).
+
+        isassigned: np.array
+            Array of booleans equal to length of 500, where order
+            is robotID 1 to 500 robotID. True if robotID is assigned in grid
+            and False if it is not.
         """
         # get xPos and yPos from robotGrid
         xrobo = np.zeros(500)
         yrobo = np.zeros(500)
         hasFiber = np.zeros(500, dtype=bool) + True
+        isassigned = np.zeros(500, dtype=bool) + True
+        mag_adj_robo = np.zeros(500) - 9999.
         for i, robotID in enumerate(self.rg.robotDict):
             if instrument == 'BOSS':
                 xrobo[i] = self.rg.robotDict[robotID].bossWokXYZ[0]
@@ -1156,6 +1211,7 @@ class DesignModeCheck(DesignMode):
                 hasFiber[i] = self.rg.robotDict[robotID].hasApogee
                 xrobo[i] = self.rg.robotDict[robotID].apWokXYZ[0]
                 yrobo[i] = self.rg.robotDict[robotID].apWokXYZ[1]
+            isassigned[i] = self.rg.robotDict[robotID].isAssigned()
 
         ra_robo, dec_robo, fieldWarn = wokxy2radec(xWok=xrobo,
                                                    yWok=yrobo,
@@ -1213,9 +1269,20 @@ class DesignModeCheck(DesignMode):
                 if r_exclude[i] > 0.:
                     dist = ang_sep(ras[i], decs[i],
                                    ra_robo, dec_robo) * 3600.
+                    if 'bright' in self.desmode_label:
+                        mag_adj = adjusted_brigh_neigh_mag(mags[i],
+                                                           dist,
+                                                           lunation='bright')
+                    else:
+                        mag_adj = adjusted_brigh_neigh_mag(mags[i],
+                                                           dist,
+                                                           lunation='dark')
                     neigh_checks[dist < r_exclude[i]] = False
+                    mag_adj_robo[dist < r_exclude[i]] = mag_adj[dist < r_exclude[i]]
+        # dont accoutn for places where no fiber
+        mag_adj_robo[~hasFiber] = -9999.
 
-        return neigh_checks, hasFiber
+        return neigh_checks, hasFiber, mag_adj_robo, isassigned
 
     def design_mode_check_all(self, verbose=True):
         """
@@ -1333,15 +1400,21 @@ class DesignModeCheck(DesignMode):
         self.bright_neighbor_check['BOSS'] = self.bright_neighbors(instrument='BOSS',
                                                                    check_type='designmode')
         check_tot = len(self.bright_neighbor_check['BOSS'][0][self.bright_neighbor_check['BOSS'][0] &
-                                                              self.bright_neighbor_check['BOSS'][1]])
-        design_tot = len(self.bright_neighbor_check['BOSS'][0][self.bright_neighbor_check['BOSS'][1]])
-        self.bright_neighbor_check['BOSS_metric'] = [check_tot, design_tot]
+                                                              self.bright_neighbor_check['BOSS'][1] &
+                                                              self.bright_neighbor_check['BOSS'][3]])
+        design_tot = len(self.bright_neighbor_check['BOSS'][0][self.bright_neighbor_check['BOSS'][1] &
+                                                               self.bright_neighbor_check['BOSS'][3]])
+        mag_adj_near_bs = self.bright_neighbor_check['BOSS'][2]
+        self.bright_neighbor_check['BOSS_metric'] = [check_tot, design_tot, mag_adj_near_bs]
         self.bright_neighbor_check['APOGEE'] = self.bright_neighbors(instrument='APOGEE',
                                                                      check_type='designmode')
         check_tot = len(self.bright_neighbor_check['APOGEE'][0][self.bright_neighbor_check['APOGEE'][0] &
-                                                                self.bright_neighbor_check['APOGEE'][1]])
-        design_tot = len(self.bright_neighbor_check['APOGEE'][0][self.bright_neighbor_check['APOGEE'][1]])
-        self.bright_neighbor_check['APOGEE_metric'] = [check_tot, design_tot]
+                                                                self.bright_neighbor_check['APOGEE'][1] &
+                                                                self.bright_neighbor_check['APOGEE'][3]])
+        design_tot = len(self.bright_neighbor_check['APOGEE'][0][self.bright_neighbor_check['APOGEE'][1] &
+                                                                 self.bright_neighbor_check['APOGEE'][3]])
+        mag_adj_near_bs = self.bright_neighbor_check['APOGEE'][2]
+        self.bright_neighbor_check['APOGEE_metric'] = [check_tot, design_tot, mag_adj_near_bs]
 
         if verbose:
             verbose_output = ''
